@@ -1,20 +1,21 @@
 # checksum.py -- core Portage functionality
-# Copyright 1998-2017 Gentoo Foundation
+# Copyright 1998-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
+# pylint: disable=ungrouped-imports
 
-import portage
-from portage.const import PRELINK_BINARY, HASHING_BLOCKSIZE
-from portage.localization import _
-from portage import os
-from portage import _encodings
-from portage import _unicode_decode, _unicode_encode
 import errno
 import functools
 import hashlib
+import portage
 import stat
 import subprocess
 import tempfile
 
+from portage import _encodings, _unicode_decode, _unicode_encode
+from portage import os
+from portage.const import HASHING_BLOCKSIZE, PRELINK_BINARY
+from portage.localization import _
+
 
 # Summary of all available hashes and their implementations,
 # most preferred first. Please keep this in sync with logic below.
@@ -32,7 +33,7 @@ import tempfile
 # SHA3_512: hashlib (3.6+), pysha3, pycrypto
 
 
-#dict of all available hash functions
+# Dict of all available hash functions
 hashfunc_map = {}
 hashorigin_map = {}
 
@@ -75,7 +76,7 @@ class _generate_hash_function:
 	def checksum_file(self, filename):
 		"""
 		Run a checksum against a file.
-	
+
 		@param filename: File to run the checksum against
 		@type filename: String
 		@return: The hash and size of the data
@@ -382,7 +383,7 @@ class _hash_filter:
 		for token in self._tokens:
 			if token in matches:
 				return True
-			elif token[:1] == "-":
+			if token[:1] == "-":
 				if token[1:] in matches:
 					return False
 		return False
